==> apache-streampipes-0.93.0-source-release.zip: apache-streampipes-0.93.0/ui/projects/streampipes/platform-services/src/public-api.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

/*
 * Public API Surface of platform-services
 */

export * from './lib/platform-services.module';

export * from './lib/apis/commons.service';
export * from './lib/apis/adapter.service';
export * from './lib/apis/adapter-monitoring.service';
export * from './lib/apis/asset-management.service';
export * from './lib/apis/data-view-data-explorer.service';
export * from './lib/apis/datalake-rest.service';
export * from './lib/apis/dashboard.service';
export * from './lib/apis/files.service';
export * from './lib/apis/functions.service';
export * from './lib/apis/general-config.service';
export * from './lib/apis/generic-storage.service';
export * from './lib/apis/labels.service';
export * from './lib/apis/mail-config.service';
export * from './lib/apis/measurement-units.service';
export * from './lib/apis/permissions.service';
export * from './lib/apis/pipeline.service';
export * from './lib/apis/pipeline-canvas-metadata.service';
export * from './lib/apis/pipeline-element.service';
export * from './lib/apis/pipeline-element-endpoint.service';
export * from './lib/apis/pipeline-element-template.service';
export * from './lib/apis/pipeline-monitoring.service';
export * from './lib/apis/pipeline-template.service';
export * from './lib/apis/semantic-types.service';
export * from './lib/apis/user.service';
export * from './lib/apis/user-admin.service';
export * from './lib/apis/user-group.service';
export * from './lib/apis/shared-dashboard.service';

export * from './lib/model/datalake/DateRange';
export * from './lib/model/datalake/DatalakeQueryParameters';
export * from './lib/model/dashboard/dashboard.model';
export * from './lib/model/email-config.model';
export * from './lib/model/general-config.model';
export * from './lib/model/measurement-unit/MeasurementUnit';
export * from './lib/model/gen/streampipes-model-client';
export * from './lib/model/gen/streampipes-model';

export * from './lib/model/datalake/data-lake-query-config.model';
export * from './lib/query/DatalakeQueryParameterBuilder';
export * from './lib/query/data-view-query-generator.service';
export * from './lib/model/user/user.model';

export * from './lib/model/assets/asset.model';
export * from './lib/model/labels/labels.model';

==> apache-streampipes-0.95.1-source-release.zip: apache-streampipes-0.95.1/ui/projects/streampipes/platform-services/src/public-api.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

/*
 * Public API Surface of platform-services
 */

export * from './lib/platform-services.module';

export * from './lib/apis/commons.service';
export * from './lib/apis/adapter.service';
export * from './lib/apis/adapter-monitoring.service';
export * from './lib/apis/asset-management.service';
export * from './lib/apis/data-view-data-explorer.service';
export * from './lib/apis/datalake-rest.service';
export * from './lib/apis/dashboard.service';
export * from './lib/apis/files.service';
export * from './lib/apis/functions.service';
export * from './lib/apis/general-config.service';
export * from './lib/apis/generic-storage.service';
export * from './lib/apis/labels.service';
export * from './lib/apis/mail-config.service';
export * from './lib/apis/measurement-units.service';
export * from './lib/apis/permissions.service';
export * from './lib/apis/pipeline.service';
export * from './lib/apis/pipeline-canvas-metadata.service';
export * from './lib/apis/pipeline-element.service';
export * from './lib/apis/extension-installation.service';
export * from './lib/apis/pipeline-element-template.service';
export * from './lib/apis/pipeline-monitoring.service';
export * from './lib/apis/pipeline-template.service';
export * from './lib/apis/semantic-types-rest.service';
export * from './lib/apis/user.service';
export * from './lib/apis/user-admin.service';
export * from './lib/apis/user-group.service';
export * from './lib/apis/shared-dashboard.service';

export * from './lib/model/datalake/DateRange';
export * from './lib/model/datalake/DatalakeQueryParameters';
export * from './lib/model/dashboard/dashboard.model';
export * from './lib/model/email-config.model';
export * from './lib/model/general-config.model';
export * from './lib/model/measurement-unit/MeasurementUnit';
export * from './lib/model/gen/streampipes-model-client';
export * from './lib/model/gen/streampipes-model';

export * from './lib/model/datalake/data-lake-query-config.model';
export * from './lib/query/DatalakeQueryParameterBuilder';
export * from './lib/query/data-view-query-generator.service';
export * from './lib/query/generic-storage-query-builder';
export * from './lib/model/user/user.model';

export * from './lib/model/assets/asset.model';
export * from './lib/model/labels/labels.model';

export * from './lib/model/types/data-type';
export * from './lib/model/types/semantic-type';
